@@ -1,6 +1,6 @@
 from twisted.internet import reactor
 from twisted.internet import defer
-from twisted.web.client import HTTPClientFactory, HTTPDownloader, _parse
+from twisted.web.client import HTTPClientFactory, _parse
 from unicodeconverter import convertToUTF8, convertToUnicode
 import cPickle
 import sha
@@ -96,7 +96,7 @@ class RequestQueuer():
 
         return deferred
 
-    def _getPage(self, url, method='GET', postdata=None, headers=None, agent="Offbeat Guides", timeout=60, cookies=None, followRedirect=1 ):
+    def _getPage(self, url, method='GET', postdata=None, headers=None, agent="AWSpider", timeout=60, cookies=None, followRedirect=1 ):
 
         if headers is None:
             headers = {}
@@ -117,9 +117,9 @@ class RequestQueuer():
         if scheme == 'https':
             from twisted.internet import ssl
             contextFactory = ssl.ClientContextFactory()
-            reactor.connectSSL(host, port, factory, contextFactory, timeout=60)
+            reactor.connectSSL(host, port, factory, contextFactory, timeout=timeout)
         else:
-            reactor.connectTCP(host, port, factory, timeout=60)
+            reactor.connectTCP(host, port, factory, timeout=timeout)
 
         factory.deferred.addCallback( self._getPageComplete, factory )
         factory.deferred.addErrback( self._getPageError, factory )
