@@ -5,6 +5,7 @@ from twisted.internet.defer import Deferred
 
 import datetime
 import time
+import calendar
 import random
 
 import logging
@@ -57,7 +58,7 @@ def _getTimeOffsetCallback( simple_telnet, server ):
     return simple_telnet.deferred
     
 def _getTimeOffsetCallback2( data, server ):
-    
+
     logger.debug( "Got time from %s." % server )
 
     t = datetime.datetime( 
@@ -66,10 +67,9 @@ def _getTimeOffsetCallback2( data, server ):
         int(data[13:15]),
         int(data[16:18]),
         int(data[19:21]),
-        int(data[22:23]),
-        tzinfo=pytz.utc )
-    
-    offset = time.mktime( t.timetuple() ) - time.time()
+        int(data[22:23]) )
+        
+    offset = calendar.timegm( t.timetuple() ) - time.time()
     return offset
 
 def getTimeOffsetTest():
@@ -80,7 +80,8 @@ def _getTimeOffsetTestCallback( offset ):
     print offset
     print time.time()
     print time.time() + offset
-
+    reactor.stop()
+    
 if __name__ == "__main__":
     import logging.handlers
     handler = logging.StreamHandler()
